@@ -22,6 +22,7 @@
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-utils.h>
 
+#include <libanjuta/interfaces/ianjuta-markable.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-editor-selection.h>
 #include <libanjuta/interfaces/ianjuta-editor-convert.h>
@@ -36,6 +37,7 @@
 #include <libanjuta/interfaces/ianjuta-editor-comment.h>
 #include <libanjuta/interfaces/ianjuta-editor-zoom.h>
 #include <libanjuta/interfaces/ianjuta-editor-goto.h>
+#include <libanjuta/interfaces/ianjuta-editor-language.h>
 
 #include <libegg/menu/egg-entry-action.h>
 
@@ -53,8 +55,6 @@
 #define AUTOFORMAT_LIST_STYLE      "autoformat.list.style"
 #define AUTOFORMAT_OPTS            "autoformat.opts"
 
-gboolean closing_state;
-
 void
 static editor_autoformat (IAnjutaEditor *te, AnjutaPreferences* prefs)
 {
@@ -105,68 +105,61 @@ static editor_autoformat (IAnjutaEditor *te, AnjutaPreferences* prefs)
 static IAnjutaEditor*
 get_current_editor(gpointer user_data)
 {
-			DocmanPlugin* plugin = (DocmanPlugin*) user_data;
+	DocmanPlugin* plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	AnjutaDocman* docman = ANJUTA_DOCMAN(plugin->docman);
 	return IANJUTA_EDITOR(anjuta_docman_get_current_editor(docman));
 }
 
 void
-on_open1_activate (GtkAction * action, gpointer user_data)
+on_open_activate (GtkAction * action, gpointer user_data)
 {
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	anjuta_docman_open_file (docman);
 }
 
 void
-on_save1_activate (GtkAction *action, gpointer user_data)
+on_save_activate (GtkAction *action, gpointer user_data)
 {
 	IAnjutaEditor *te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
 		return;
-	if (ianjuta_file_get_uri(IANJUTA_FILE(te), NULL) == NULL)
-	{
-		anjuta_docman_set_current_editor (docman, te);
-		anjuta_docman_save_as_file (docman);
-		return;
-	}
-	else
-	{
-		/* TODO: Error checking */
-		ianjuta_file_savable_save(IANJUTA_FILE_SAVABLE(te), NULL);
-	}
-	if (closing_state)
-	{
-		anjuta_docman_remove_editor (docman, te);
-		closing_state = FALSE;
-	}
+	
+	anjuta_docman_save_editor (docman, te, NULL);
 }
 
 void
-on_save_as1_activate (GtkAction * action, gpointer user_data)
+on_save_as_activate (GtkAction * action, gpointer user_data)
 {
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	IAnjutaEditor *te;
+	
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
-	anjuta_docman_save_as_file (docman);
+	
+	te = anjuta_docman_get_current_editor (docman);
+	if (te == NULL)
+		return;
+	
+	anjuta_docman_save_editor_as (docman, te, NULL);
 }
 
 void
-on_save_all1_activate (GtkAction * action, gpointer user_data)
+on_save_all_activate (GtkAction * action, gpointer user_data)
 {
 	GList *node;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	
 	node = anjuta_docman_get_all_editors (docman);
@@ -189,14 +182,14 @@ on_save_all1_activate (GtkAction * action, gpointer user_data)
 }
 
 void
-on_close_file1_activate (GtkAction * action, gpointer user_data)
+on_close_file_activate (GtkAction * action, gpointer user_data)
 {
 	AnjutaDocman *docman;
 	IAnjutaEditor *te;
 	GtkWidget *parent;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -210,7 +203,6 @@ on_close_file1_activate (GtkAction * action, gpointer user_data)
 		GtkWidget *dialog;
 		gint res;
 		
-		closing_state = TRUE;
 		mesg = g_strdup_printf (_("The file '%s' is not saved.\n"
 								"Do you want to save it before closing?"),
 								ianjuta_editor_get_filename(te, NULL));
@@ -228,28 +220,29 @@ on_close_file1_activate (GtkAction * action, gpointer user_data)
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 										 GTK_RESPONSE_CANCEL);
 		res = gtk_dialog_run (GTK_DIALOG (dialog));
+		
+		gtk_widget_destroy (dialog);
 		if (res == GTK_RESPONSE_YES)
-			on_save1_activate (NULL, user_data);
+		{
+			anjuta_docman_save_editor (docman, te, NULL);
+			anjuta_docman_remove_editor (docman, te);
+		}
 		else if (res == GTK_RESPONSE_NO)
 		{
 			anjuta_docman_remove_editor (docman, te);
-			closing_state = FALSE;
 		}
-		else
-			closing_state = FALSE;
-		gtk_widget_destroy (dialog);
 	}
 	else
 		anjuta_docman_remove_editor (docman, te);
 }
 
 void
-on_close_all_file1_activate (GtkAction * action, gpointer user_data)
+on_close_all_file_activate (GtkAction * action, gpointer user_data)
 {
 	GList *node;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	
 	/* Close all 'saved' files */
@@ -272,7 +265,7 @@ on_close_all_file1_activate (GtkAction * action, gpointer user_data)
 }
 
 void
-on_reload_file1_activate (GtkAction * action, gpointer user_data)
+on_reload_file_activate (GtkAction * action, gpointer user_data)
 {
 	IAnjutaEditor *te;
 	gchar mesg[256];
@@ -281,7 +274,7 @@ on_reload_file1_activate (GtkAction * action, gpointer user_data)
 	DocmanPlugin *plugin;
 	AnjutaDocman *docman;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -319,7 +312,7 @@ anjuta_print_cb (GtkAction *action, gpointer user_data)
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -334,7 +327,7 @@ anjuta_print_preview_cb (GtkAction * action, gpointer user_data)
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -393,15 +386,15 @@ on_editor_command_select_all_activate (GtkAction * action, gpointer data)
 	GtkWidget *widget=NULL;
 	GtkWidget *main_window=NULL;
 	
-	main_window= (GtkWidget*) gtk_window_list_toplevels ()->data;
-    widget = gtk_window_get_focus (GTK_WINDOW(main_window));
+	main_window = GTK_WIDGET (gtk_window_list_toplevels ()->data);
+	widget = gtk_window_get_focus (GTK_WINDOW(main_window));
    
 	if (widget && GTK_IS_EDITABLE (widget))
 	{
 		gtk_editable_select_region (GTK_EDITABLE (widget), 0, -1);
 	}
 	else
-    {
+	{
 		ianjuta_editor_selection_select_all (IANJUTA_EDITOR_SELECTION (get_current_editor(data)),
 																	   NULL);
 	}
@@ -441,10 +434,10 @@ on_editor_command_redo_activate (GtkAction * action, gpointer data)
 void
 on_editor_command_cut_activate (GtkAction * action, gpointer data)
 {
-	GtkWidget *widget=NULL;
-	GtkWidget *main_window=NULL;
+	GtkWidget *widget;
+	GtkWidget *main_window;
 	
-	main_window= (GtkWidget*) gtk_window_list_toplevels ()->data;
+	main_window = GTK_WIDGET (gtk_window_list_toplevels ()->data);
 	widget = gtk_window_get_focus (GTK_WINDOW(main_window));
 
 	if (widget && GTK_IS_EDITABLE (widget))
@@ -460,10 +453,10 @@ on_editor_command_cut_activate (GtkAction * action, gpointer data)
 void
 on_editor_command_copy_activate (GtkAction * action, gpointer data)
 {	
-	GtkWidget *widget=NULL;
-	GtkWidget *main_window=NULL;
+	GtkWidget *widget;
+	GtkWidget *main_window;
 	
-	main_window= (GtkWidget*) gtk_window_list_toplevels ()->data;
+	main_window = GTK_WIDGET (gtk_window_list_toplevels ()->data);
 	widget = gtk_window_get_focus (GTK_WINDOW(main_window));
 
 	if (widget && GTK_IS_EDITABLE (widget))
@@ -479,10 +472,10 @@ on_editor_command_copy_activate (GtkAction * action, gpointer data)
 void
 on_editor_command_paste_activate (GtkAction * action, gpointer data)
 {
-	GtkWidget *widget=NULL;
-	GtkWidget *main_window=NULL;
+	GtkWidget *widget;
+	GtkWidget *main_window;
 	
-	main_window= (GtkWidget*) gtk_window_list_toplevels ()->data;
+	main_window = GTK_WIDGET (gtk_window_list_toplevels ()->data);
 	widget = gtk_window_get_focus (GTK_WINDOW(main_window));
 
 	if (widget && GTK_IS_EDITABLE (widget))
@@ -498,11 +491,11 @@ on_editor_command_paste_activate (GtkAction * action, gpointer data)
 void
 on_editor_command_clear_activate (GtkAction * action, gpointer data)
 {
-	GtkWidget *widget=NULL;
-	GtkWidget *main_window=NULL;
+	GtkWidget *widget;
+	GtkWidget *main_window;
 	gint start, end;
 	
-	main_window= (GtkWidget*) gtk_window_list_toplevels ()->data;
+	main_window = GTK_WIDGET (gtk_window_list_toplevels ()->data);
 	widget = gtk_window_get_focus (GTK_WINDOW(main_window));
 
 	if (widget && GTK_IS_EDITABLE (widget))
@@ -588,7 +581,7 @@ on_prev_history (GtkAction *action, gpointer user_data)
 {
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	an_file_history_back (docman);
 }
@@ -598,7 +591,7 @@ on_next_history (GtkAction *action, gpointer user_data)
 {
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	an_file_history_forward (docman);
 }
@@ -609,7 +602,7 @@ on_comment_block (GtkAction * action, gpointer user_data)
 	IAnjutaEditor* te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	ianjuta_editor_comment_block(IANJUTA_EDITOR_COMMENT(te), NULL);
@@ -620,7 +613,7 @@ void on_comment_box (GtkAction * action, gpointer user_data)
 	IAnjutaEditor* te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	ianjuta_editor_comment_box(IANJUTA_EDITOR_COMMENT(te), NULL);
@@ -631,7 +624,7 @@ void on_comment_stream (GtkAction * action, gpointer user_data)
 	IAnjutaEditor* te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	ianjuta_editor_comment_stream(IANJUTA_EDITOR_COMMENT(te), NULL);
@@ -641,7 +634,7 @@ void
 on_goto_activate (GtkAction *action, gpointer user_data)
 {
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	anjuta_ui_activate_action_by_path (plugin->ui,
 		"ActionGroupNavigation/ActionEditGotoLineEntry");
 }
@@ -657,7 +650,7 @@ on_toolbar_goto_clicked (GtkAction *action, gpointer user_data)
 	guint line;
 	const gchar *line_ascii;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	g_object_get(G_OBJECT(plugin), "shell", &shell, NULL);
@@ -682,15 +675,14 @@ on_toolbar_goto_clicked (GtkAction *action, gpointer user_data)
 	{
 		line = atoi (line_ascii);
 		ianjuta_editor_goto_line(te, line, NULL);
-		/* FIXME
-		if (text_editor_goto_line (te, line, TRUE, TRUE) == FALSE)
+		if (IANJUTA_IS_MARKABLE (te))
 		{
-			GtkWidget *parent;
-			parent = gtk_widget_get_toplevel (GTK_WIDGET (te));
-			anjuta_util_dialog_error (GTK_WINDOW (parent),
-									  _("There is no line number %d in \"%s\"."),
-									  line, te->filename);
-		}*/
+			ianjuta_markable_delete_all_markers (IANJUTA_MARKABLE (te),
+												 IANJUTA_MARKABLE_LINEMARKER,
+												 NULL);
+			ianjuta_markable_mark (IANJUTA_MARKABLE (te),
+								   line, IANJUTA_MARKABLE_LINEMARKER, NULL);
+		}
 	}
 }
 
@@ -702,7 +694,7 @@ on_goto_line_no1_activate (GtkAction * action, gpointer user_data)
 	AnjutaDocman *docman;
 	IAnjutaEditor *te;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	
@@ -720,7 +712,7 @@ on_goto_block_start1_activate (GtkAction * action, gpointer user_data)
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -735,7 +727,7 @@ on_goto_block_end1_activate (GtkAction * action, gpointer user_data)
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	if (te == NULL)
@@ -756,7 +748,7 @@ on_editor_linenos1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_LINENUMBERS_MARGIN, state);
@@ -767,7 +759,7 @@ on_editor_markers1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_MARKER_MARGIN, state);
@@ -778,7 +770,7 @@ on_editor_codefold1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_FOLD_MARGIN, state);
@@ -789,7 +781,7 @@ on_editor_indentguides1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_INDENTATION_GUIDES, state);
@@ -800,7 +792,7 @@ on_editor_whitespaces1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_WHITE_SPACES, state);
@@ -811,7 +803,7 @@ on_editor_eolchars1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_EOL, state);
@@ -822,7 +814,7 @@ on_editor_linewrap1_activate (GtkAction * action, gpointer user_data)
 {
 	gboolean state;
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	state = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	anjuta_preferences_set_int (plugin->prefs,
 								VIEW_LINE_WRAP, state);
@@ -832,13 +824,16 @@ void
 on_zoom_in_text_activate (GtkAction * action, gpointer user_data)
 {
 	DocmanPlugin *plugin;
-	IAnjutaEditor* te;
 	AnjutaDocman *docman;
-	plugin = (DocmanPlugin *) user_data;
+	IAnjutaEditor *te;
+	
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	
-	ianjuta_editor_zoom_in(IANJUTA_EDITOR_ZOOM(te), NULL);
+	if (te == NULL)
+		return;
+	ianjuta_editor_zoom_in (IANJUTA_EDITOR_ZOOM (te), NULL);
 }
 
 void
@@ -846,50 +841,52 @@ on_zoom_out_text_activate (GtkAction * action, gpointer user_data)
 {
 	DocmanPlugin *plugin;
 	AnjutaDocman *docman;
-	IAnjutaEditor* te;
-	plugin = (DocmanPlugin *) user_data;
+	IAnjutaEditor *te;
+	
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
 	
-	ianjuta_editor_zoom_out(IANJUTA_EDITOR_ZOOM(te), NULL);
+	if (te == NULL)
+		return;
+	ianjuta_editor_zoom_out (IANJUTA_EDITOR_ZOOM (te), NULL);
 }
 
 void
 on_force_hilite_activate (GtkWidget *menuitem, gpointer user_data)
 {
-	#if 0
-	TextEditor *te;
+	IAnjutaEditor *te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
-	const gchar *file_extension;
+	const gchar *language_code;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
-	file_extension = g_object_get_data (G_OBJECT (menuitem), "file_extension");
+	language_code = g_object_get_data (G_OBJECT (menuitem), "language_code");
 	
 	if (te == NULL)
 		return;
-	text_editor_set_hilite_type (te, file_extension);
-	text_editor_hilite (te, TRUE);
-	#endif
+	if (language_code && IANJUTA_IS_EDITOR_LANGUAGE (te))
+		ianjuta_editor_language_set_language (IANJUTA_EDITOR_LANGUAGE (te),
+											  language_code, NULL);
 }
 
 void
 on_indent1_activate (GtkAction * action, gpointer user_data)
 {
-    //trying to restore line no where i was before autoformat invoked
-    gint lineno;
+	//trying to restore line no where i was before autoformat invoked
+	gint lineno;
 	IAnjutaEditor *te;
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	te = anjuta_docman_get_current_editor (docman);
-    if (te == NULL)
+	if (te == NULL)
 		return;
-    lineno = ianjuta_editor_get_lineno(te, NULL);
+	lineno = ianjuta_editor_get_lineno(te, NULL);
 	editor_autoformat (te, plugin->prefs);
 	ianjuta_editor_goto_line (te, lineno, NULL);
 }
@@ -898,7 +895,7 @@ void
 on_format_indent_style_clicked (GtkAction * action, gpointer user_data)
 {
 	DocmanPlugin *plugin;
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	gtk_signal_emit_by_name (GTK_OBJECT (plugin->prefs),
 										 "activate");
 }
@@ -1019,7 +1016,7 @@ on_swap_activate (GtkAction *action, gpointer user_data)
 	AnjutaDocman *docman;
 	DocmanPlugin *plugin;
 	
-	plugin = (DocmanPlugin *) user_data;
+	plugin = ANJUTA_PLUGIN_DOCMAN (user_data);
 	docman = ANJUTA_DOCMAN (plugin->docman);
 	
 	te = anjuta_docman_get_current_editor (docman);
