@@ -19,7 +19,18 @@
 */
 
 #include <config.h>
-#include <gtk/gtk.h>
+
+#ifdef GLADEUI_OLD
+# include <glade.h>
+#else
+# ifdef GLADEUI_LAST_PUBLIC
+#   include <glade.h>
+#   include <glade-design-view.h>
+# else /* SVN */
+#   include <gladeui/glade.h>
+#   include <gladeui/glade-design-view.h>
+# endif
+#endif
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
@@ -28,23 +39,6 @@
 #include <libanjuta/interfaces/ianjuta-wizard.h>
 #include <libanjuta/interfaces/ianjuta-help.h>
 
-#include <glade.h>
-#include <glade-palette.h>
-#include <glade-editor.h>
-#include <glade-clipboard.h>
-#include <glade-clipboard-view.h>
-#include <glade-widget.h>
-#include <glade-widget-class.h>
-#include <glade-property.h>
-#include <glade-property-class.h>
-#include <glade-project.h>
-#include <glade-project-view.h>
-#include <glade-placeholder.h>
-#include <glade-command.h>
-#include <glade-debug.h>
-#include <glade-utils.h>
-#include <glade-app.h>
-
 #include "plugin.h"
 
 #define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-glade.ui"
@@ -60,6 +54,9 @@ struct _GladePluginPriv
 	GtkActionGroup *action_group;
 	GladeApp *gpw;
 	GladeProjectView *view;
+#ifndef GLADEUI_OLD
+	GtkWidget *design_notebook;
+#endif
 	GtkWidget *view_box;
 	GtkWidget *projects_combo;
 };
@@ -157,7 +154,7 @@ on_cut_activated (GtkAction *action, GladePlugin *plugin)
 static void
 on_paste_activated (GtkAction *action, GladePlugin *plugin)
 {
-	glade_app_command_paste ();
+	glade_app_command_paste (NULL);
 }
 
 static void
@@ -349,11 +346,11 @@ glade_confirm_close_project (GladePlugin *plugin, GladeProject *project)
 }
 
 static void
-on_api_help(GladeEditor* editor, 
-	const gchar* book,
-	const gchar* page,
-	const gchar* search,
-	GladePlugin* plugin)
+on_api_help (GladeEditor* editor, 
+			 const gchar* book,
+			 const gchar* page,
+			 const gchar* search,
+			 GladePlugin* plugin)
 {
 	gchar *book_comm = NULL, *page_comm = NULL;
 	gchar *string;
@@ -384,8 +381,16 @@ on_api_help(GladeEditor* editor,
 static void
 glade_do_close (GladePlugin *plugin, GladeProject *project)
 {
-	// FIXME: Remove from combo.	
+#ifndef GLADEUI_OLD
+	GtkWidget *design_view;
 
+	design_view = g_object_get_data (G_OBJECT (project), "design_view");
+	gtk_notebook_remove_page (GTK_NOTEBOOK (plugin->priv->design_notebook),
+							  gtk_notebook_page_num (GTK_NOTEBOOK
+													 (plugin->priv->design_notebook),
+													 design_view));
+	gtk_widget_destroy (design_view);
+#endif
 	glade_app_remove_project (project);
 }
 
@@ -445,8 +450,21 @@ on_glade_project_changed (GtkComboBox *combo, GladePlugin *plugin)
 	if (gtk_combo_box_get_active_iter (combo, &iter))
 	{
 		GladeProject *project;
+		
+#ifndef GLADEUI_OLD
+		GtkWidget *design_view;
+		gint design_pagenum;
+#endif
 		gtk_tree_model_get (model, &iter, PROJECT_COL, &project, -1);
 		glade_app_set_project (project);
+		
+#ifndef GLADEUI_OLD
+		design_view = g_object_get_data (G_OBJECT (project), "design_view");
+		design_pagenum = gtk_notebook_page_num (GTK_NOTEBOOK (plugin->priv->design_notebook),
+												design_view);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (plugin->priv->design_notebook),
+									   design_pagenum);
+#endif
 	}
 }
 
@@ -607,6 +625,56 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 	g_list_free (files);
 }
 
+/* FIXME: Glade does not allow destroying its (singleton) widgets.
+ * Make sure they are removed when the application is destroyed
+ * without the plugin unloaded.
+ */
+static void
+on_shell_destroy (AnjutaShell *shell, GladePlugin *glade_plugin)
+{
+	GtkWidget *wid;
+	GtkWidget *parent;
+	
+	/* Remove widgets before the container destroyes them */
+	wid = GTK_WIDGET (glade_app_get_palette ());
+	parent = gtk_widget_get_parent (wid);
+	gtk_container_remove (GTK_CONTAINER (parent), wid);
+	
+	wid = GTK_WIDGET (glade_app_get_editor ());
+	parent = gtk_widget_get_parent (wid);
+	gtk_container_remove (GTK_CONTAINER (parent), wid);
+	
+	wid = GTK_WIDGET (glade_plugin->priv->view_box);
+	parent = gtk_widget_get_parent (wid);
+	gtk_container_remove (GTK_CONTAINER (parent), wid);
+}
+
+#ifndef GLADEUI_OLD
+static void
+glade_plugin_add_project (GladePlugin *glade_plugin, GladeProject *project)
+{
+	GtkWidget *view;
+	GladePluginPriv *priv;
+	
+ 	g_return_if_fail (GLADE_IS_PROJECT (project));
+ 	
+	priv = glade_plugin->priv;
+ 	view = glade_design_view_new (project);	
+	gtk_widget_show (view);
+	g_object_set_data (G_OBJECT (project), "design_view", view);
+	glade_app_add_project (project);
+
+	gtk_notebook_append_page (GTK_NOTEBOOK (priv->design_notebook), GTK_WIDGET (view), NULL);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->design_notebook), -1);	
+}
+#else
+static void
+glade_plugin_add_project (GladePlugin *glade_plugin, GladeProject *project)
+{
+	glade_app_add_project (project);
+}
+#endif
+
 static gboolean
 activate_plugin (AnjutaPlugin *plugin)
 {
@@ -619,41 +687,62 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	DEBUG_PRINT ("GladePlugin: Activating Glade plugin...");
 	
-	glade_plugin = (GladePlugin*) plugin;
+	glade_plugin = ANJUTA_PLUGIN_GLADE (plugin);
 	
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	priv = glade_plugin->priv;
 	
 	register_stock_icons (plugin);
-	priv->gpw = g_object_new(GLADE_TYPE_APP, NULL);
-	glade_app_set_window (GTK_WIDGET (ANJUTA_PLUGIN(plugin)->shell));
-    glade_app_set_transient_parent (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell));
+	
+	if (!priv->gpw)
+	{
+		priv->gpw = g_object_new(GLADE_TYPE_APP, NULL);
+	
+		glade_app_set_window (GTK_WIDGET (ANJUTA_PLUGIN(plugin)->shell));
+		glade_app_set_transient_parent (GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell));
     	
-	/* Create a view for us */
-	priv->view_box = gtk_vbox_new (FALSE, 0);
-	store = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, NULL);
-	
-	priv->projects_combo = gtk_combo_box_new ();
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->projects_combo),
-								renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (priv->projects_combo),
-									renderer, "text", NAME_COL, NULL);
-	gtk_combo_box_set_model (GTK_COMBO_BOX (priv->projects_combo),
-							 GTK_TREE_MODEL (store));
-	g_object_unref (G_OBJECT (store));
-	gtk_box_pack_start (GTK_BOX (priv->view_box), priv->projects_combo,
-						FALSE, FALSE, 0);
-	
-	priv->view = glade_project_view_new (GLADE_PROJECT_VIEW_TREE);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->view),
-					GTK_POLICY_NEVER, GTK_POLICY_NEVER);
+		/* Create a view for us */
+		priv->view_box = gtk_vbox_new (FALSE, 0);
+		store = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING,
+									G_TYPE_POINTER, NULL);
+		
+		priv->projects_combo = gtk_combo_box_new ();
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->projects_combo),
+									renderer, TRUE);
+		gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (priv->projects_combo),
+										renderer, "text", NAME_COL, NULL);
+		gtk_combo_box_set_model (GTK_COMBO_BOX (priv->projects_combo),
+								 GTK_TREE_MODEL (store));
+		g_object_unref (G_OBJECT (store));
+		gtk_box_pack_start (GTK_BOX (priv->view_box), priv->projects_combo,
+							FALSE, FALSE, 0);
+#ifndef GLADEUI_OLD
+		priv->view = GLADE_PROJECT_VIEW (glade_project_view_new ());
+#else
+		/* Old glade-3 */
+		priv->view = GLADE_PROJECT_VIEW (glade_project_view_new (GLADE_PROJECT_VIEW_TREE));
+#endif
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->view),
+						GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	glade_app_add_project_view (priv->view);
-	gtk_box_pack_start (GTK_BOX (priv->view_box), GTK_WIDGET (priv->view),
-						TRUE, TRUE, 0);
-	
-	gtk_widget_show_all (priv->view_box);
+		glade_app_add_project_view (priv->view);
+		gtk_box_pack_start (GTK_BOX (priv->view_box), GTK_WIDGET (priv->view),
+							TRUE, TRUE, 0);
+		
+		gtk_widget_show_all (priv->view_box);
+		gtk_notebook_set_scrollable (GTK_NOTEBOOK (glade_app_get_editor ()->notebook),
+									 TRUE);
+		gtk_notebook_popup_enable (GTK_NOTEBOOK (glade_app_get_editor ()->notebook));
+		
+#ifndef GLADEUI_OLD
+		/* Create design_notebook */
+		priv->design_notebook = gtk_notebook_new ();
+		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (priv->design_notebook), FALSE);
+		gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->design_notebook), FALSE);
+		gtk_widget_show (priv->design_notebook);
+#endif
+	}
 	
 	g_signal_connect (G_OBJECT (priv->projects_combo), "changed",
 					  G_CALLBACK (on_glade_project_changed), plugin);
@@ -661,38 +750,57 @@ activate_plugin (AnjutaPlugin *plugin)
 					  G_CALLBACK (glade_update_ui), plugin);
 	
 	g_signal_connect(G_OBJECT(glade_app_get_editor()), "gtk-doc-search",
-		G_CALLBACK(on_api_help), plugin);
+					 G_CALLBACK(on_api_help), plugin);
+	
+	g_signal_connect(G_OBJECT(plugin->shell), "destroy",
+					 G_CALLBACK(on_shell_destroy), plugin);
 	
-	gtk_notebook_set_scrollable (GTK_NOTEBOOK (glade_app_get_editor ()->notebook),
-								 TRUE);
-	gtk_notebook_popup_enable (GTK_NOTEBOOK (glade_app_get_editor ()->notebook));
-
 	/* Add action group */
 	priv->action_group = 
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupGlade",
-										_("Glade operations"),
-										actions,
-										G_N_ELEMENTS (actions),
-										GETTEXT_PACKAGE, glade_plugin);
+											_("Glade operations"),
+											actions,
+											G_N_ELEMENTS (actions),
+											GETTEXT_PACKAGE, TRUE,
+											glade_plugin);
 	/* Add UI */
 	priv->uiid = anjuta_ui_merge (ui, UI_FILE);
 	
+	/* FIXME: Glade doesn't want to die these widget, so
+	 * hold a permenent refs on them
+	 */
+	g_object_ref (glade_app_get_palette ());
+	g_object_ref (glade_app_get_editor ());
+	g_object_ref (priv->view_box);
+#ifndef GLADEUI_OLD
+	g_object_ref (priv->design_notebook);
+#endif
+	gtk_widget_show (GTK_WIDGET (glade_app_get_palette ()));
+	gtk_widget_show (GTK_WIDGET (glade_app_get_editor ()));
+	
 	/* Add widgets */
-	anjuta_shell_add_widget (ANJUTA_PLUGIN (plugin)->shell,
-							 GTK_WIDGET (glade_app_get_palette ()),
-							 "AnjutaGladePalette", _("Palette"),
-							 "glade-plugin-icon",
-							 ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
 	anjuta_shell_add_widget (ANJUTA_PLUGIN (plugin)->shell,
 							 GTK_WIDGET (priv->view_box),
 							 "AnjutaGladeTree", _("Widgets"),
 							 "glade-plugin-icon",
 							 ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
+	anjuta_shell_add_widget (ANJUTA_PLUGIN (plugin)->shell,
+							 GTK_WIDGET (glade_app_get_palette ()),
+							 "AnjutaGladePalette", _("Palette"),
+							 "glade-plugin-icon",
+							 ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
 	anjuta_shell_add_widget (ANJUTA_PLUGIN (plugin)->shell,
 							 GTK_WIDGET (glade_app_get_editor ()),
 							 "AnjutaGladeEditor", _("Properties"),
 							 "glade-plugin-icon",
 							 ANJUTA_SHELL_PLACEMENT_CENTER, NULL);
+#ifndef GLADEUI_OLD
+	anjuta_shell_add_widget (ANJUTA_PLUGIN (plugin)->shell,
+							 GTK_WIDGET (priv->design_notebook),
+							 "AnjutaGladeDesigner", _("Designer"),
+							 "glade-plugin-icon",
+							 ANJUTA_SHELL_PLACEMENT_CENTER, NULL);
+#endif
 	/* Connect to save session */
 	g_signal_connect (G_OBJECT (plugin->shell), "save_session",
 					  G_CALLBACK (on_session_save), plugin);
@@ -704,15 +812,29 @@ deactivate_plugin (AnjutaPlugin *plugin)
 {
 	GladePluginPriv *priv;
 	
-	priv = ((GladePlugin*)plugin)->priv;
+	priv = ANJUTA_PLUGIN_GLADE (plugin)->priv;
 	
 	AnjutaUI *ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	
 	DEBUG_PRINT ("GladePlugin: Dectivating Glade plugin...");
 	
+	/* Disconnect signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
 										  G_CALLBACK (on_session_save), plugin);
 	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (priv->projects_combo),
+										  G_CALLBACK (on_glade_project_changed),
+										  plugin);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (priv->gpw),
+										  G_CALLBACK (glade_update_ui),
+										  plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT(glade_app_get_editor()),
+										  G_CALLBACK(on_api_help), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
+										  G_CALLBACK (on_shell_destroy),
+										  plugin);
 	/* Remove widgets */
 	anjuta_shell_remove_widget (plugin->shell,
 								GTK_WIDGET (glade_app_get_palette ()),
@@ -723,6 +845,11 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	anjuta_shell_remove_widget (plugin->shell,
 								GTK_WIDGET (priv->view_box),
 								NULL);
+#ifndef GLADEUI_OLD
+	anjuta_shell_remove_widget (plugin->shell,
+								GTK_WIDGET (priv->design_notebook),
+								NULL);
+#endif
 	
 	/* Remove UI */
 	anjuta_ui_unmerge (ui, priv->uiid);
@@ -730,8 +857,9 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	/* Remove action group */
 	anjuta_ui_remove_action_group (ui, priv->action_group);
 	
-	/* Destroy glade */
-	g_object_unref (G_OBJECT (priv->gpw));
+	/* FIXME: Don't destroy glade, since it doesn't want to */
+	/* g_object_unref (G_OBJECT (priv->gpw)); */
+	/* priv->gpw = NULL */
 	
 	priv->uiid = 0;
 	priv->action_group = NULL;
@@ -743,7 +871,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 static void
 glade_plugin_dispose (GObject *obj)
 {
-	// GladePlugin *plugin = (GladePlugin*)obj;
+	/* GladePlugin *plugin = ANJUTA_PLUGIN_GLADE (obj); */
 	
 	/* FIXME: Glade widgets should be destroyed */
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
@@ -752,7 +880,7 @@ glade_plugin_dispose (GObject *obj)
 static void
 glade_plugin_finalize (GObject *obj)
 {
-	GladePlugin *plugin = (GladePlugin*)obj;
+	GladePlugin *plugin = ANJUTA_PLUGIN_GLADE (obj);
 	g_free (plugin->priv);
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
 }
@@ -761,7 +889,7 @@ static void
 glade_plugin_instance_init (GObject *obj)
 {
 	GladePluginPriv *priv;
-	GladePlugin *plugin = (GladePlugin*)obj;
+	GladePlugin *plugin = ANJUTA_PLUGIN_GLADE (obj);
 	
 	plugin->priv = (GladePluginPriv *) g_new0 (GladePluginPriv, 1);
 	priv = plugin->priv;
@@ -793,7 +921,7 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	
 	g_return_if_fail (uri != NULL);
 	
-	priv = ((GladePlugin*)G_OBJECT (ifile))->priv;
+	priv = ANJUTA_PLUGIN_GLADE (ifile)->priv;
 	
 	filename = gnome_vfs_get_local_path_from_uri (uri);
 	if (!filename)
@@ -814,7 +942,7 @@ ifile_open (IAnjutaFile *ifile, const gchar *uri, GError **err)
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter, NAME_COL, project->name,
 						PROJECT_COL, project, -1);
-	glade_app_add_project (project);
+	glade_plugin_add_project (ANJUTA_PLUGIN_GLADE (ifile), project);
 	anjuta_shell_present_widget (ANJUTA_PLUGIN (ifile)->shell, priv->view_box, NULL);
 }
 
@@ -832,7 +960,7 @@ iwizard_activate (IAnjutaWizard *iwizard, GError **err)
 	GtkListStore *store;
 	GtkTreeIter iter;
 	
-	priv = ((GladePlugin*)G_OBJECT (iwizard))->priv;
+	priv = ANJUTA_PLUGIN_GLADE (iwizard)->priv;
 
 	project = glade_project_new (TRUE);
 	if (!project)
@@ -845,8 +973,9 @@ iwizard_activate (IAnjutaWizard *iwizard, GError **err)
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter, NAME_COL, project->name,
 						PROJECT_COL, project, -1);
-	glade_app_add_project (project);
-	anjuta_shell_present_widget (ANJUTA_PLUGIN (iwizard)->shell, priv->view_box, NULL);
+	glade_plugin_add_project (ANJUTA_PLUGIN_GLADE (iwizard), project);
+	anjuta_shell_present_widget (ANJUTA_PLUGIN (iwizard)->shell,
+				     GTK_WIDGET (glade_app_get_palette ()), NULL);
 }
 
 static void
